==> maDB_1.4.0.tar.gz: maDB/man/createJOINQuery.Rd <==
\name{createJOINQuery}
\alias{createJOINQuery}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Create a SQL query that joins two or more tables}
\description{
This function creates SQL query strings that allow to join all available tables from the \code{maDB} database.
}
\usage{
createJOINQuery(join, with, select = "*", r = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{join}{One of the two database tables that should be joined.}
  \item{with}{The database table with which the first one should be joined.}
  \item{select}{The attributes (column names) of the tables that should be returned. By default every column will be returned.}
  \item{r}{Attribute for joining the \code{comparisons} table with any other table. If \code{r=TRUE} the entries of the \code{comparisons} table will be joined with the other table using the information for the red signal channel, if \code{r=FALSE} the informtion for the green signal channel will be used.}
}
\details{
Basically this function should ease the usage for the \code{maDB} database. The list of tables that can be joined are: \code{comparisons, signal\_channels, arrays, samples and experiments}.
}
\value{
A string that can be used in the \code{\link{dbSendQuery}} function to retrieve the data.
}
\author{Johannes Rainer}
\seealso{\code{\link{dbSendQuery}}, \code{\link{dbGetComparisons}}}
\examples{
##
## join the comparison table with the samples table
createJOINQuery(join="comparisons",with="samples")


}
\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/createJOINQuery.Rd <==
\name{createJOINQuery}
\alias{createJOINQuery}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Create a SQL query that joins two or more tables}
\description{
This function creates SQL query strings that allow to join all available tables from the \code{maDB} database.
}
\usage{
createJOINQuery(join, with, select = "*", r = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{join}{One of the two database tables that should be joined.}
  \item{with}{The database table with which the first one should be joined.}
  \item{select}{The attributes (column names) of the tables that should be returned. By default every column will be returned.}
  \item{r}{Attribute for joining the \code{comparisons} table with any other table. If \code{r=TRUE} the entries of the \code{comparisons} table will be joined with the other table using the information for the red signal channel, if \code{r=FALSE} the informtion for the green signal channel will be used.}
}
\details{
Basically this function should ease the usage for the \code{maDB} database. The list of tables that can be joined are: \code{comparisons, signal\_channels, arrays, samples and experiments}.
}
\value{
A string that can be used in the \code{dbSendQuery} (package RdbiPgSQL) function to retrieve the data.
}
\author{Johannes Rainer}
\seealso{\code{\link{dbGetComparisons}}}
\examples{
##
## join the comparison table with the samples table
createJOINQuery(join="comparisons",with="samples")


}
\keyword{data}
